dag_cbor.encoding
=================

.. automodule:: dag_cbor.encoding

canonical_order_dict
--------------------

.. autofunction:: dag_cbor.encoding.canonical_order_dict

check_key_compliance
--------------------

.. autofunction:: dag_cbor.encoding.check_key_compliance

encode
------

.. autofunction:: dag_cbor.encoding.encode

dag_cbor.encoding.__all__
-------------------------

The following members were explicitly reexported using ``__all__``:

    - :py:class:`dag_cbor.encoding.err.CBOREncodingError`
    - :py:class:`dag_cbor.encoding.err.DAGCBOREncodingError`
